'use strict';

var curry = require('./curry.js');
var _apply3 = require('./_apply3.js');

/**
 * Applies a function to three values.
 *
 * @function
 * @param {Function} f The function to apply.
 * @param a The first value.
 * @param b The second value.
 * @param c The third value.
 * @returns The result of `f(a, b, c)`.
 * @example
 *
 * import { apply3 } from 'fkit'
 * const sayHi = (a, b, c) => ['Hi', a, b, c, '!'].join(' ')
 * apply3(sayHi, 'Ms', 'Jane', 'Appleseed') // Hi Ms Jane Appleseed!
 */

var apply3 = curry(_apply3);

module.exports = apply3;
