'use strict';

var curry = require('./curry.js');
var _applyMethod3 = require('./_applyMethod3.js');

/**
 * Applies a method to three values.
 *
 * @function
 * @param {String} k The method to apply.
 * @param a The first value.
 * @param b The second value.
 * @param c The third value.
 * @param {Object} o The object.
 * @returns The result of the method `k` of object `o` applied to the values
 * `a`, `b`, and `c`.
 * @example
 *
 * import { applyMethod3 } from 'fkit'
 * const person = { sayHi: (a, b, c) => ['Hi', a, b, c, '!'].join(' ') }
 * applyMethod3('sayHi', 'Ms', 'Jane', 'Appleseed', person) // Hi Ms Jane Appleseed!
 */

var applyMethod3 = curry(_applyMethod3);

module.exports = applyMethod3;
