'use strict';

var curry = require('./curry.js');
var _applyRight = require('./_applyRight.js');

/**
 * Applies a function to a value. This is similar to `apply`, however the order
 * of the arguments is flipped.
 *
 * @function
 * @param a The value.
 * @param {Function} f The function to apply.
 * @returns The result of `f(a)`.
 * @example
 *
 * import { applyRight } from 'fkit'
 * function sayHi (a) { return ['Hi', a, '!'].join(' ') }
 * applyRight('Jane', sayHi) // Hi Jane!
 */

var applyRight = curry(_applyRight);

module.exports = applyRight;
