'use strict';

var curry = require('./curry.js');
require('./chunk-ba04ad2f.js');
require('./chunk-5a196674.js');
require('./empty.js');
require('./head.js');
require('./tail.js');
require('./_prepend.js');
var _removeBy = require('./_removeBy.js');

/**
 * Removes the first occurance of an element from a list using a comparator
 * function.
 *
 * The comparator function `f` compares two elements, `a` and `b`. If the
 * elements are both considered to equal, then the comparator function should
 * return `true`. Otherwise it should return `false`.
 *
 * @function
 * @param {Function} f The comparator function.
 * @param a The value to find.
 * @param {Array|String} bs The list.
 * @returns {Array|String} A list with the first occurance of the element `a`
 * removed from the list of `bs`.
 * @example
 *
 * import { removeBy } from 'fkit'
 * removeBy((a, b) => a === b, 2, [1, 2, 3]) // [1, 3]
 * removeBy((a, b) => a === b, 'f', 'foo') // 'oo'
 */

var removeBy = curry(_removeBy);

module.exports = removeBy;
