'use strict';

require('./curry.js');
var __chunk_1 = require('./chunk-ba04ad2f.js');
require('./chunk-d7703e54.js');
require('./_append.js');
require('./append.js');
require('./flip.js');
var __chunk_3 = require('./chunk-56a5551b.js');
var array = require('./array.js');
var _fold = require('./_fold.js');
require('./_randomInt.js');
var randomInt = require('./randomInt.js');

/**
 * Shuffles a list using the [Fisher-Yates
 * algorithm](http://en.wikipedia.org/wiki/Fisher-Yates_shuffle).
 *
 * @param {Array|String} as The list.
 * @returns {Array|String} A list that contains the elements in the list of
 * `as` randomly shuffled.
 * @example
 *
 * import { shuffle } from 'fkit'
 * shuffle([1, 2, 3]) // [2, 3, 1]
 * shuffle('abc') // 'bca'
 */

function shuffle(as) {
  var i = -1;

  var f = function f(b, a) {
    var j = randomInt(0, ++i);
    b[i] = b[j];
    b[j] = a;
    return b;
  };

  var r = array(as.length);
  var bs = _fold(f, r, as);
  var s = __chunk_1.isString(as) ? '' : [];
  return __chunk_3.concatWith(s, bs);
}

module.exports = shuffle;
